@@ -8,10 +8,12 @@ protected:
 public:
   virtual void generate() = 0; //sample with replacement
   IntegerVector get_shuffled_index(bool which_class) const; // get index 
+  virtual ~Sampler_base();
 };
 
 class Sampler_Stratified : public Sampler_base { //class for stratified sampling
 public:
   virtual void generate();
   Sampler_Stratified(IntegerVector true_class);
+  virtual ~Sampler_Stratified();
 };
